@@ -6,7 +6,7 @@ use vars qw[$VERSION %utilities];
 use Module::CoreList;
 use Module::CoreList::TieHashDelta;
 
-$VERSION = '5.20140914';
+$VERSION = '5.20141002';
 
 sub utilities {
     my $perl = shift;
@@ -822,6 +822,20 @@ my %delta = (
         removed => {
         }
     },
+    5.018003 => {
+        delta_from => 5.018000,
+        changed => {
+        },
+        removed => {
+        }
+    },
+    5.018004 => {
+        delta_from => 5.018000,
+        changed => {
+        },
+        removed => {
+        }
+    },
     5.019000 => {
         delta_from => 5.018000,
         changed => {
@@ -957,6 +971,13 @@ my %delta = (
         removed => {
         }
     },
+    5.021004 => {
+        delta_from => 5.021003,
+        changed => {
+        },
+        removed => {
+        }
+    },
 );
 
 for my $version (sort { $a <=> $b } keys %delta) {
